package com.bonus.material.lease.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.lease.domain.LeaseTeamInfo;
import com.bonus.material.lease.service.ILeaseTeamInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 项目部班组管理Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "项目部班组管理接口")
@RestController
@RequestMapping("/lease_team_info")
public class LeaseTeamInfoController extends BaseController {
    @Autowired
    private ILeaseTeamInfoService leaseTeamInfoService;

    /**
     * 查询项目部班组管理列表
     */
    @ApiOperation(value = "查询项目部班组管理列表")
    @RequiresPermissions("lease:info:list")
    @GetMapping("/list")
    public TableDataInfo list(LeaseTeamInfo leaseTeamInfo) {
        startPage();
        List<LeaseTeamInfo> list = leaseTeamInfoService.selectLeaseTeamInfoList(leaseTeamInfo);
        return getDataTable(list);
    }

    /**
     * 导出项目部班组管理列表
     */
    @ApiOperation(value = "导出项目部班组管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:info:export")
    @SysLog(title = "项目部班组管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出项目部班组管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, LeaseTeamInfo leaseTeamInfo) {
        List<LeaseTeamInfo> list = leaseTeamInfoService.selectLeaseTeamInfoList(leaseTeamInfo);
        ExcelUtil<LeaseTeamInfo> util = new ExcelUtil<LeaseTeamInfo>(LeaseTeamInfo.class);
        util.exportExcel(response, list, "项目部班组管理数据");
    }

    /**
     * 获取项目部班组管理详细信息
     */
    @ApiOperation(value = "获取项目部班组管理详细信息")
    @RequiresPermissions("lease:info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(leaseTeamInfoService.selectLeaseTeamInfoById(id));
    }

    /**
     * 新增项目部班组管理
     */
    @ApiOperation(value = "新增项目部班组管理")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:info:add")
    @SysLog(title = "项目部班组管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增项目部班组管理")
    @PostMapping
    public AjaxResult add(@RequestBody LeaseTeamInfo leaseTeamInfo) {
        try {
            return toAjax(leaseTeamInfoService.insertLeaseTeamInfo(leaseTeamInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改项目部班组管理
     */
    @ApiOperation(value = "修改项目部班组管理")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:info:edit")
    @SysLog(title = "项目部班组管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改项目部班组管理")
    @PutMapping
    public AjaxResult edit(@RequestBody LeaseTeamInfo leaseTeamInfo) {
        try {
            return toAjax(leaseTeamInfoService.updateLeaseTeamInfo(leaseTeamInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除项目部班组管理
     */
    @ApiOperation(value = "删除项目部班组管理")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:info:remove")
    @SysLog(title = "项目部班组管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除项目部班组管理")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(leaseTeamInfoService.deleteLeaseTeamInfoByIds(ids));
    }
}
